jupyter_lsp: Multi-Language Server WebSocket proxy for Jupyter Notebook/Lab server
==================================================================================

Description
-----------

Multi-Language Server WebSocket proxy for Jupyter Notebook/Lab server

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/jupyter-lsp/

